#!/bin/sh
# q2maptoq1map.sh -- convert a quake 2 map file to quake 1 format
#
# This is a bash shell script for linux, but you can also run it under windows if
# you use cygwin from http://www.cygwin.com/.
#
# Usage: ./q2maptoq1map.sh <sourcemap> <outputmap>
#         <sourcemap>: the map file in Quake 2 format that you want to convert
#         <outputmap>: the file the converted map should be written to
#
# Example: 
#           ./q2maptoq1map.sh quake2/baseq2/maps/someq2map.map quake1/id1/maps/convertedmap.map

##### init global stuff, settings #####

at="[Q2T1]"

##### functions #####

usage()
{
       echo "$at q2maptoq1map -- convert a Quake 2 .map file to a Quake 1 map format"
       echo "$at   Usage: ./q2maptoq1map.sh <source> <target>"
       echo "$at     * <source> : a map file in Quake 2 map format"
       echo "$at     * <target> : where to write the converted output map file"
       echo "$at   Example: ./q2maptoq1map.sh quake2/baseq2/maps/myq2map.map quake/id1/maps/convertedmap.map"
       exit 0
}


##### parse and check args #####

source="$1"
target="$2"

if [ -z $source ]; then
   echo "$at ERROR: No source file specified."
   usage
fi


if [ -z $target ]; then
   echo "$at ERROR: No target file specified."
   usage
fi

echo "$at Converting Quake 2 map file '$source' to Quake 1 format, writing output to file '$target'."

##### here we go #####

touch $target && awk '{ print $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14, $15, $16, $17, $18, $19, $20, $21 }' $source >> $target && echo "$at Done, exiting." && exit 1

# only reached if tghe line above failed
echo "$at ERROR: Conversion failed." && exit 0

